==> codeforlife_portal-1.0.0.post0.dev726-py2.py3-none-any.whl: portal/tests/pageObjects/portal/teach/add_independent_student_to_class_page.py <==
# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2018, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from portal.tests.pageObjects.portal.teach.added_independent_student_to_class_page import \
    AddedIndependentStudentToClassPage
from portal.tests.pageObjects.portal.teach.teach_base_page import TeachBasePage

from selenium.webdriver.common.by import By


class AddIndependentStudentToClassPage(TeachBasePage):
    def __init__(self, browser):
        super(AddIndependentStudentToClassPage, self).__init__(browser)

        assert self.on_correct_page('add_independent_student_to_class')

    def _rename(self):
        self.browser.find_element_by_id('id_name').clear()
        self.browser.find_element_by_id('id_name').send_keys("Student3")

    def save(self):
        self._rename()
        self.wait_for_element_to_be_clickable((By.ID, 'save_student_name_button'))
        self.browser.find_element_by_id('save_student_name_button').click()

        return AddedIndependentStudentToClassPage(self.browser)

==> codeforlife_portal-1.2.0-py2.py3-none-any.whl: portal/tests/pageObjects/portal/teach/add_independent_student_to_class_page.py <==
# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2018, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from portal.tests.pageObjects.portal.teach.added_independent_student_to_class_page import \
    AddedIndependentStudentToClassPage
from portal.tests.pageObjects.portal.teach.teach_base_page import TeachBasePage

from selenium.webdriver.common.by import By


class AddIndependentStudentToClassPage(TeachBasePage):
    def __init__(self, browser):
        super(AddIndependentStudentToClassPage, self).__init__(browser)

        assert self.on_correct_page('add_independent_student_to_class')

    def _rename(self, name):
        self.browser.find_element_by_id('id_name').clear()
        self.browser.find_element_by_id('id_name').send_keys(name)

    def save(self, name):
        self._rename(name)
        self.wait_for_element_to_be_clickable((By.ID, 'save_student_name_button'))
        self.browser.find_element_by_id('save_student_name_button').click()

        return AddedIndependentStudentToClassPage(self.browser)
